@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '0.016';
+our $VERSION = '0.017';
 $VERSION = eval $VERSION;
 
 use parent 'Module::Build';
@@ -263,9 +263,6 @@ sub ACTION_code {
 
     $self->depends_on('alien_code');
     $self->SUPER::ACTION_code;
-
-    # copy the compiled files into blib if running under blib scheme
-    $self->depends_on('alien_install') if $self->notes('alien_blib_scheme') || $self->alien_stage_install;
   }
   
   my $module = $self->module_name;
@@ -291,6 +288,14 @@ EOF
   }
 }
 
+sub process_share_dir_files {
+  my $self = shift;
+  $self->SUPER::process_share_dir_files(@_);
+  
+  # copy the compiled files into blib if running under blib scheme
+  $self->depends_on('alien_install') if $self->notes('alien_blib_scheme') || $self->alien_stage_install;
+}
+
 sub ACTION_alien_code {
   my $self = shift;
   local $| = 1; # don't buffer stdout
@@ -402,9 +407,9 @@ sub ACTION_install {
   my $self = shift;
   $self->SUPER::ACTION_install;
   if($self->alien_stage_install) {
-    $self->alien_relocation_fixup if $self->alien_stage_install;
+    $self->alien_relocation_fixup;
   } else {
-    $self->depends_on('alien_install') unless $self->alien_stage_install;
+    $self->depends_on('alien_install');
   }
 }
 
@@ -468,20 +473,24 @@ sub ACTION_alien_install {
   $self->alien_refresh_manual_pkgconfig( $self->alien_library_destination );
   $self->config_data( 'finished_installing' => 1 );
 
-  # to refresh config_data
-  $self->SUPER::ACTION_config_data;
-
-  if ( $self->notes( 'alien_blib_scheme') ) {
-    # reinstall config_data to blib
-    $self->process_files_by_extension('pm');
+  if ( $self->notes( 'alien_blib_scheme') || $self->alien_stage_install) {
+  
+    ### TODO: empty if should be claned up before 0.017.
+    ### we used to call process_files_by_extension('pm')
+    ### here, but with gh#121 it is unecessary
+    ## reinstall config_data to blib
+    #$self->process_files_by_extension('pm');
 
   } else {
+
+    # to refresh config_data
+    $self->SUPER::ACTION_config_data;
+
     # reinstall config_data
     $self->SUPER::ACTION_install;
 
     # refresh the packlist
-    $self->alien_refresh_packlist( $self->alien_library_destination )
-      unless $self->alien_stage_install;
+    $self->alien_refresh_packlist( $self->alien_library_destination );
   }
 }
 
